@@ -70,7 +70,12 @@ class QuickUnitPlugin(Plugin):
             return
 
         self.verbosity = options.verbosity
-        self.prefixes = options.quickunit_prefix or ["tests/unit/"]
+        if options.quickunit_prefix:
+            self.prefixes = options.quickunit_prefix
+            if len(self.prefixes) == 0:
+                self.prefixes = self.prefixes[0].split('\n')
+        else:
+            self.prefixes = ["tests/unit/"]
         self.parent = 'master'
 
         self.logger = logging.getLogger(__name__)
